@@ -1,9 +1,12 @@
+mod utils;
 use std::{collections::HashMap, env, sync::Arc, thread::sleep, time::Duration};
+use utils::mock_event_logging_adapter::MockEventLoggingAdapter;
+use utils::mock_specs_adapter::MockSpecsAdapter;
 
 use statsig_rust::{
     dyn_value, evaluation::evaluation_types::AnyConfigEvaluation, hashing::djb2,
-    output_logger::LogLevel, DynamicValue, Statsig, StatsigHttpIdListsAdapter, StatsigOptions,
-    StatsigUser,
+    output_logger::LogLevel, DynamicValue, SpecsSource, Statsig, StatsigHttpIdListsAdapter,
+    StatsigOptions, StatsigUser,
 };
 
 fn get_sdk_key() -> String {
@@ -160,6 +163,72 @@ async fn test_user_agent_disabled() {
     assert!(!statsig_3.check_gate(&user, "test_ua"));
 }
 
+#[tokio::test]
+async fn test_initialize_with_details() {
+    let statsig = Statsig::new(&get_sdk_key(), None);
+    let details = statsig.initialize_with_details().await.unwrap();
+    assert!(details.init_success);
+    assert!(details.is_config_spec_ready);
+    assert!(details.source == SpecsSource::Network);
+    assert!(details.failure_details.is_none());
+    assert!(details.is_id_list_ready.is_none());
+}
+
+#[tokio::test]
+async fn test_initialize_with_details_failure() {
+    let statsig = Statsig::new("invalid-sdk-key", None);
+    let details = statsig.initialize_with_details().await.unwrap();
+    assert!(details.init_success);
+    assert!(!details.is_config_spec_ready);
+    assert!(details.source == SpecsSource::NoValues);
+    assert!(details.failure_details.is_some());
+    assert!(details.is_id_list_ready.is_none());
+}
+
+#[tokio::test]
+async fn test_initialize_with_details_with_id_lists() {
+    let id_list_opt = StatsigOptions {
+        enable_id_lists: Some(true),
+        ..StatsigOptions::new()
+    };
+    let statsig = Statsig::new(&get_sdk_key(), Some(Arc::new(id_list_opt)));
+    let details = statsig.initialize_with_details().await.unwrap();
+    assert!(details.init_success);
+    assert!(details.is_config_spec_ready);
+    assert!(details.source == SpecsSource::Network);
+    assert!(details.failure_details.is_none());
+    assert!(details.is_id_list_ready.is_some());
+}
+
+#[tokio::test]
+async fn test_identify() {
+    let mock_event_logger = Arc::new(MockEventLoggingAdapter::new());
+    let opts = StatsigOptions {
+        event_logging_adapter: Some(mock_event_logger.clone()),
+        specs_adapter: Some(Arc::new(MockSpecsAdapter::with_data(
+            "tests/data/eval_proj_dcs.json",
+        ))),
+        ..StatsigOptions::default()
+    };
+
+    let statsig = Statsig::new(&get_sdk_key(), Some(Arc::new(opts)));
+    statsig.initialize().await.unwrap();
+
+    let user = StatsigUser::with_user_id("test-user-for-identify".to_string());
+    statsig.identify(&user);
+
+    sleep(Duration::from_millis(1));
+    statsig.flush_events().await;
+
+    let first_event = mock_event_logger.force_get_first_event().await;
+    assert_eq!(first_event.get("eventName").unwrap(), "statsig::identify");
+    assert!(first_event.get("value").unwrap().is_null());
+    assert!(first_event.get("metadata").unwrap().is_null());
+
+    let user_obj = first_event.get("user").unwrap();
+    assert_eq!(user_obj.get("userID").unwrap(), "test-user-for-identify");
+}
+
 // Todo: rewrite this test such that it isn't reaching into internal implementation details
 // #[tokio::test]
 // async fn do_not_double_start_background_tasks() {
